% Non-isothermal CSTR with multiple steady-states

% operating condition:
par(1) = 20;        % volume (m^3)
par(2) = 1000;      % specific mass (kg/m^3)
par(3) = 4;         % specific heat (kJ/kg.K)
par(4) = -7000;     % reaction heat (kJ/kmol)
%par(5) = 1e4*3600;   % pre-exponential factor (1/h)
%par(5) = 71.6169*3600;   % pre-exponential factor (1/h), Hopf
par(5) = 89*3600;   % pre-exponential factor (1/h), complexo
par(6) = 6e4;       % activation energy (kJ/kmol)
par(7) = 0.16*3600; % overall heat transfer coeficient (kJ/h.m^2.K)
par(8) = 25;        % heat transfer area (m^2)
par(9) = 8.3144;    % universal constant (kJ/kmol.K)
V = par(1);
rho = par(2);
cp = par(3);
DH = par(4);
ko = par(5);
E = par(6);
U = par(7);
At = par(8);
R = par(9);
F = 6; %1e-3*3600;      % flowrate (m^3/h)
Ce = 300;           % inlet concentration (kmol/m^3)
Te = 320;           % inlet temperature (K)
Tw = 315;           % jacket temperature (K)
tau = V/F;          % tempo de residencia medio (h)

% initial condition
Co = 10;          % initial concentration (kmol/m^3)
To = 650;         % initial temperature (K)

gama=E/(R*Te);
alfa=(-DH*Ce)/(rho*cp*Te);
Da=ko*exp(-gama)*tau;
beta=U*At/(rho*cp*F);

x_0 = [Co To];
T = [0
     40
     80
     120
     160
     200
     240
     280
     320
     360
     400];

VAZAO=0;

if VAZAO,
U = [F Ce Te Tw
     1.1*F Ce Te Tw
     F Ce Te Tw
     0.9*F Ce Te Tw
     F Ce Te Tw
     1.1*F Ce Te Tw
     F Ce Te Tw
     0.9*F Ce Te Tw
     F Ce Te Tw
     1.1*F Ce Te Tw
     F Ce Te Tw];
else
U = [F Ce Te Tw
     F Ce Te 1.1*Tw
     F Ce Te Tw
     F Ce Te 0.9*Tw
     F Ce Te Tw
     F Ce Te 1.1*Tw
     F Ce Te Tw
     F Ce Te 0.9*Tw
     F Ce Te Tw
     F Ce Te 1.1*Tw
     F Ce Te Tw];
end

tf = T(end);      % final time (h)
Rtol = 1e-6;      % relative tolerance
Atol = 1e-10;     % absolute tolerance

%op = simset('Solver','ode15s','RelTol',Rtol,'AbsTol',Atol);
[t,x] = sim('cstr');
