% cstr
% Non-isothermal CSTR with multiple steady-states

% operating condition:
par(1) = 13.5;      % volume (m^3)
par(2) = 1000;      % specific mass (kg/m^3)
par(3) = 4;         % specific heat (kJ/kg.K)
par(4) = -7000;     % reaction heat (kJ/kmol)
%par(5) = 71.6169*3600;   % pre-exponential factor (1/h), Hopf
par(5) = 89*3600;   % pre-exponential factor (1/h), complexo
par(6) = 6e4;       % activation energy (kJ/kmol)
par(7) = 300;       % overall heat transfer coeficient (kJ/h.m^2.K)
par(8) = 25;        % heat transfer area (m^2)
par(9) = 8.3144;    % universal constant (kJ/kmol.K)
V = par(1);
rho = par(2);
cp = par(3);
DH = par(4);
ko = par(5);
E = par(6);
U = par(7);
At = par(8);
R = par(9);
F = 3.5;            % flowrate (m^3/h)
Ce = 300;           % inlet concentration (kmol/m^3)
Te = 350;           % inlet temperature (K)
Tw = 300;           % jacket temperature (K)
tau = V/F;          % tempo de residencia medio (h)

% initial condition
Co = 10;          % initial concentration (kmol/m^3)
To = 650;         % initial temperature (K)

gama=E/(R*Te);
alfa=(-DH*Ce)/(rho*cp*Te);
Da=ko*exp(-gama)*tau;
beta=U*At/(rho*cp*F);

x_0 = [Co To];
T = [0
     400];
U = [F Ce Te Tw
     F Ce Te Tw];
     
tf = T(end);      % final time (h)
Rtol = 1e-6;      % relative tolerance
Atol = 1e-10;     % absolute tolerance

%op = simset('Solver','ode15s','RelTol',Rtol,'AbsTol',Atol);
%[t,x] = sim('cstr');

xs1 = [13.13; 659.46];
[X1,L1] = eig([-1.6458e-3 -3.4282e-4; 2.7542e-3 4.8934e-4]);
X1=X1*50;
xs2 = [132.87; 523.01];
[X2,L2] = eig([-1.626e-4 -3.1753e-4; 1.5852e-4 4.4509e-4]);
X2=X2*50;
xs3 = [299.86; 332.72];
[X3,L3] = eig([-7.205e-5 -6.622e-7; 5.9285e-8 -1.0944e-4]);
X3=X3*50;

dx1 = [0 350];
dx2 = [290 800];
figure(1);
axis([dx1 dx2]);
hold on
c='gr';

for i=1:150
  x_0 = rand(2,1).*([dx1(2);dx2(2)]-[dx1(1);dx2(1)])+[dx1(1);dx2(1)];
  [t,x] = sim('cstr');
  plot(x(:,1),x(:,2));
end

if isreal(L1)
  [z,i]=sort(abs(diag(L1)));
  plot([-X1(1,1) X1(1,1)]+xs1(1),[-X1(2,1) X1(2,1)]+xs1(2),c(i(1)),[-X1(1,2) X1(1,2)]+xs1(1),[-X1(2,2) X1(2,2)]+xs1(2),c(i(2)));
end

if isreal(L2)
  [z,i]=sort(abs(diag(L2)));
  plot([-X2(1,1) X2(1,1)]+xs2(1),[-X2(2,1) X2(2,1)]+xs2(2),c(i(1)),[-X2(1,2) X2(1,2)]+xs2(1),[-X2(2,2) X2(2,2)]+xs2(2),c(i(2)));
end

if isreal(L3)
  [z,i]=sort(abs(diag(L3)));
  plot([-X3(1,1) X3(1,1)]+xs3(1),[-X3(2,1) X3(2,1)]+xs3(2),c(i(1)),[-X3(1,2) X3(1,2)]+xs3(1),[-X3(2,2) X3(2,2)]+xs3(2),c(i(2)));
end

plot(dx1,[0 0],'k',[0 0],dx2,'k');
plot(xs1(1),xs1(2),'ro',xs2(1),xs2(2),'ro',xs3(1),xs3(2),'ro');
xlabel('x_1'); ylabel('x_2');
