% Non-isothermal CSTR

global R U ro Cp Hr Ea ko D Cv A Tw x F Caf Tf

   R   = 8.3144; % 'kJ/kmol/K';
	U   = 300; % 'kJ/h/m^2/K';
	ro  = 1000; % 'kg/m^3';
	Cp  = 4; % 'kJ/kg/K';
	Hr  = -7000; % 'kJ/kmol';
	Ea  = 6e4; % 'kJ/kmol';
	ko  = 89 * 3600; % '1/h';
	D   = 3.2; % 'm';
   Cv  = 2.7; % 'm^2.5/h';
   A = pi * D^2 / 4;
	x   = 1;
   Tw  = 300; % 'K';
	F   = 3.5; % 'm^3/h'
   Caf = 300; % 'kmol/m^3';
	Tf  = 350; % 'K';   
   
% Jacobian matriz - obtained in EMSO
J1=[-0.000036 0.000000 0.000000 
   -12.285870 -0.001657 -0.342117 
   0.015923 0.000003 0.000488];
L1=eig(J1);
SR=max(abs(L1))/min(abs(L1))

y0 = [1.7 50 580];  % initial condition
[t,y] = ode45('CSTR_sedo',[0 100],y0);

disp('RK explicit'); n=length(t)

[t1,y1] = ode15s('CSTR_sedo',[0 100],y0);

disp('BDF implicit'); n=length(t1)

figure(1)
subplot(3,1,1); plot(t,y(:,1),t1,y1(:,1)); ylabel('h (m)'); xlabel('time (h)');
subplot(3,1,2); plot(t,y(:,2),t1,y1(:,2)); ylabel('Ca (kmol/m^3)'); xlabel('time (h)');
subplot(3,1,3); plot(t,y(:,3),t1,y1(:,3)); ylabel('T (K)'); xlabel('time (h)');

disp('**** Reducing Cp 10x ****');
Cp  = 4/10; % 'kJ/kg/K';

% Jacobian matriz - obtained in EMSO
J2=[-0.000036 0.000000 0.000000 
   -12.837432 -0.154404 -0.120812 
   0.095230 0.002701 0.001658];
L2=eig(J2);
SR=max(abs(L2))/min(abs(L2))

[t,y] = ode45('CSTR_sedo',[0 100],y0);

disp('RK explicit'); n=length(t)

[t1,y1] = ode15s('CSTR_sedo',[0 100],y0);

disp('BDF implicit'); n=length(t1)

figure(2)
subplot(3,1,1); plot(t,y(:,1),t1,y1(:,1)); ylabel('h (m)'); xlabel('time (h)');
subplot(3,1,2); plot(t,y(:,2),t1,y1(:,2)); ylabel('Ca (kmol/m^3)'); xlabel('time (h)');
subplot(3,1,3); plot(t,y(:,3),t1,y1(:,3)); ylabel('T (K)'); xlabel('time (h)');
